@@ -34,8 +34,7 @@ def convert_store(input_store, duplicatestyle="msgctxt"):
     """converts a subtitle file to a .po file..."""
     output_store = po.pofile()
     output_header = output_store.header()
-    output_header.addnote("extracted from %s" % input_store.filename,
-                          "developer")
+    output_header.addnote("extracted from %s" % input_store.filename, "developer")
 
     for input_unit in input_store.units:
         output_unit = convert_unit(input_unit, "developer")
@@ -45,14 +44,16 @@ def convert_store(input_store, duplicatestyle="msgctxt"):
     return output_store
 
 
-def merge_store(template_store, input_store, blankmsgstr=False,
-                duplicatestyle="msgctxt"):
+def merge_store(
+    template_store, input_store, blankmsgstr=False, duplicatestyle="msgctxt"
+):
     """converts two subtitle files to a .po file..."""
     output_store = po.pofile()
     output_header = output_store.header()
-    output_header.addnote("extracted from %s, %s" %
-                          (template_store.filename, input_store.filename),
-                          "developer")
+    output_header.addnote(
+        f"extracted from {template_store.filename}, {input_store.filename}",
+        "developer",
+    )
 
     input_store.makeindex()
     for template_unit in template_store.units:
@@ -70,8 +71,9 @@ def merge_store(template_store, input_store, blankmsgstr=False,
                 origpo.target = translatedpo.source
             output_store.addunit(origpo)
         elif translatedpo is not None:
-            logger.error("error converting original subtitle definition %s",
-                         origpo.name)
+            logger.error(
+                "error converting original subtitle definition %s", origpo.name
+            )
     output_store.removeduplicates(duplicatestyle)
     return output_store
 
@@ -91,21 +93,22 @@ def convert_unit(input_unit, commenttype):
     return output_unit
 
 
-def convertsub(input_file, output_file, template_file=None, pot=False,
-               duplicatestyle="msgctxt"):
+def convertsub(
+    input_file, output_file, template_file=None, pot=False, duplicatestyle="msgctxt"
+):
     """Reads in *input_file* using translate.subtitles, converts using
     :class:`sub2po`, writes to *output_file*.
     """
     from translate.storage import subtitles
+
     input_store = subtitles.SubtitleFile(input_file)
     if template_file is None:
-        output_store = convert_store(input_store,
-                                     duplicatestyle=duplicatestyle)
+        output_store = convert_store(input_store, duplicatestyle=duplicatestyle)
     else:
         template_store = subtitles.SubtitleFile(template_file)
-        output_store = merge_store(template_store, input_store,
-                                   blankmsgstr=pot,
-                                   duplicatestyle=duplicatestyle)
+        output_store = merge_store(
+            template_store, input_store, blankmsgstr=pot, duplicatestyle=duplicatestyle
+        )
     if output_store.isempty():
         return 0
     output_store.serialize(output_file)
@@ -114,18 +117,24 @@ def convertsub(input_file, output_file, template_file=None, pot=False,
 
 def main(argv=None):
     from translate.convert import convert
+
     formats = {
-        "srt": ("po", convertsub), ("srt", "srt"): ("po", convertsub),
-        "sub": ("po", convertsub), ("sub", "sub"): ("po", convertsub),
-        "ssa": ("po", convertsub), ("ssa", "ssa"): ("po", convertsub),
-        "ass": ("po", convertsub), ("ass", "ass"): ("po", convertsub),
+        "srt": ("po", convertsub),
+        ("srt", "srt"): ("po", convertsub),
+        "sub": ("po", convertsub),
+        ("sub", "sub"): ("po", convertsub),
+        "ssa": ("po", convertsub),
+        ("ssa", "ssa"): ("po", convertsub),
+        "ass": ("po", convertsub),
+        ("ass", "ass"): ("po", convertsub),
     }
-    parser = convert.ConvertOptionParser(formats, usetemplates=True,
-                                         usepots=True, description=__doc__)
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=True, usepots=True, description=__doc__
+    )
     parser.add_duplicates_option()
     parser.passthrough.append("pot")
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
