@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007-2008 Zuza Software Foundation
 #
@@ -59,11 +58,9 @@ TODOs and Ideas for possible features:
   - phrases
 """
 
-from __future__ import unicode_literals
 
 import logging
 import re
-import six
 
 from translate.lang import data
 
@@ -71,7 +68,7 @@ from translate.lang import data
 logger = logging.getLogger(__name__)
 
 
-class Common(object):
+class Common:
     """This class is the common parent class for all language classes."""
 
     code = ""
@@ -157,8 +154,18 @@ class Common(object):
     miscpunc = "…±°¹²³·©®×£¥€"
     """The middle dot (·) is used by Greek and Georgian."""
 
-    punctuation = "".join([commonpunc, quotes, invertedpunc, rtlpunc, CJKpunc,
-                           indicpunc, ethiopicpunc, miscpunc])
+    punctuation = "".join(
+        [
+            commonpunc,
+            quotes,
+            invertedpunc,
+            rtlpunc,
+            CJKpunc,
+            indicpunc,
+            ethiopicpunc,
+            miscpunc,
+        ]
+    )
     """We include many types of punctuation here, simply since this is only
     meant to determine if something is punctuation. Hopefully we catch some
     languages which might not be represented with modules. Most languages won't
@@ -168,17 +175,21 @@ class Common(object):
     """These marks can indicate a sentence end. Once again we try to account
     for many languages. Most langauges won't need to override this."""
 
-    #The following tries to account for a lot of things. For the best idea of
-    #what works, see test_common.py. We try to ignore abbreviations, for
-    #example, by checking that the following sentence doesn't start with lower
-    #case or numbers.
-    sentencere = re.compile(r"""
+    # The following tries to account for a lot of things. For the best idea of
+    # what works, see test_common.py. We try to ignore abbreviations, for
+    # example, by checking that the following sentence doesn't start with lower
+    # case or numbers.
+    sentencere = re.compile(
+        r"""
         (?s)        # make . also match newlines
         .*?         # anything, but match non-greedy
         [%s]        # the puntuation for sentence ending
         \s+         # the spacing after the puntuation
         (?=[^a-zа-џ\d])  # lookahead that next part starts with caps
-        """ % sentenceend, re.VERBOSE | re.UNICODE)
+        """
+        % sentenceend,
+        re.VERBOSE | re.UNICODE,
+    )
 
     puncdict = {}
     """A dictionary of punctuation transformation rules that can be used by
@@ -232,8 +243,7 @@ class Common(object):
         while code:
             langdata = data.get_language(code)
             if langdata:
-                language.fullname, language.nplurals, \
-                    language.pluralequation = langdata
+                language.fullname, language.nplurals, language.pluralequation = langdata
                 break
             code = data.simplercode(code)
         return language
@@ -266,13 +276,13 @@ class Common(object):
         """Converts the punctuation in a string according to the rules of the
         language.
         """
-        #TODO: look at po::escapeforpo() for performance idea
+        # TODO: look at po::escapeforpo() for performance idea
         if not text:
             return text
         ellipses_end = text.endswith("...")
         if ellipses_end:
             text = text[:-3]
-        for source, target in six.iteritems(cls.puncdict):
+        for source, target in cls.puncdict.items():
             text = text.replace(source, target)
         if ellipses_end:
             if "..." in cls.puncdict:
@@ -284,8 +294,7 @@ class Common(object):
         # As a simple improvement for messages ending in ellipses (...), we
         # test that the last character is different from the second last
         # This is only relevant if the string has two characters or more
-        if ((text[-1] + " " in cls.puncdict) and
-            (len(text) < 2 or text[-2] != text[-1])):
+        if (text[-1] + " " in cls.puncdict) and (len(text) < 2 or text[-2] != text[-1]):
             text = text[:-1] + cls.puncdict[text[-1] + " "].rstrip()
         return text
 
@@ -321,10 +330,11 @@ class Common(object):
             if l > 9:
                 extra = cls.length_difference(l)
                 if extra > 0:
-                    text = text[:extra].replace('\n', '') + text
+                    text = text[:extra].replace("\n", "") + text
                 else:
                     text = text[-extra:]
             return text
+
         expanded = []
         for subtext in text.split("\n\n"):
             expanded.append(alter_it(subtext))
@@ -334,8 +344,8 @@ class Common(object):
     @classmethod
     def character_iter(cls, text):
         """Returns an iterator over the characters in text."""
-        #We don't return more than one consecutive whitespace character
-        prev = 'A'
+        # We don't return more than one consecutive whitespace character
+        prev = "A"
         for c in text:
             if c.isspace() and prev.isspace():
                 continue
@@ -346,12 +356,12 @@ class Common(object):
     @classmethod
     def characters(cls, text):
         """Returns a list of characters in text."""
-        return [c for c in cls.character_iter(text)]
+        return list(cls.character_iter(text))
 
     @classmethod
     def word_iter(cls, text):
         """Returns an iterator over the words in text."""
-        #TODO: Consider replacing puctuation with space before split()
+        # TODO: Consider replacing puctuation with space before split()
         for w in text.split():
             word = w.strip(cls.punctuation)
             if word:
@@ -360,7 +370,7 @@ class Common(object):
     @classmethod
     def words(cls, text):
         """Returns a list of words in text."""
-        return [w for w in cls.word_iter(text)]
+        return list(cls.word_iter(text))
 
     @classmethod
     def sentence_iter(cls, text, strip=True):
@@ -383,7 +393,7 @@ class Common(object):
     @classmethod
     def sentences(cls, text, strip=True):
         """Returns a list of sentences in text."""
-        return [s for s in cls.sentence_iter(text, strip=strip)]
+        return list(cls.sentence_iter(text, strip=strip))
 
     @classmethod
     def capsstart(cls, text):
